@@ -259,7 +259,14 @@ def delay(*args):
     args = remove_nesting(args)
     input = str(parseExpression(args[0]))
     offset = str(parseExpression(args[1]))
-    initial = str(parseExpression(args[2]))
+
+    try:
+        initial = str(parseExpression(args[2]))
+    except:
+        pattern = r"(^|[^a-zA-Z_\\.])t($|[^a-zA-Z_\\.])"
+        clean = re.compile(pattern)
+        initial = re.sub(clean, r'\1(self.starttime)\2', input)
+
 
     pattern = r"(^|[^a-zA-Z_\\.])t($|[^a-zA-Z_\\.])"
     clean = re.compile(pattern)
@@ -622,6 +629,7 @@ def savediv_(*args):
         return "( "+ str(onzero) + ")" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(denominator) + ")"
     else:
         return '(' + str(nominator) + ' / ' + str(denominator) + ")"
+
 def history_(*args):
     args = remove_nesting(args)
 
